@@ -81,6 +81,7 @@ Out of the box implementation of the Construct without any override will set the
 
 * Configure least privilege access IAM role for Lambda function
 * Enable reusing connections with Keep-Alive for NodeJs Lambda function
+* Enable X-Ray Tracing
 
 ### AWS Step Function
 
@@ -203,13 +204,9 @@ class LambdaToStepFunctionProps:
         :summary:: Properties for the LambdaToStepFunction class.
         """
         if isinstance(state_machine_props, dict):
-            state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(
-                **state_machine_props
-            )
+            state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(**state_machine_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
-                **lambda_function_props
-            )
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         self._values = {
             "state_machine_props": state_machine_props,
         }
